# manifold-markets-python
[![CircleCI](https://circleci.com/gh/vluzko/manifold-markets-python.svg?style=svg)](https://circleci.com/gh/vluzko/manifold-markets-python)
[![Documentation Status](https://readthedocs.org/projects/manifold-markets-python/badge/?version=latest)](https://manifold-markets-python.readthedocs.io/en/latest/?badge=latest)


Tools for analyzing [Manifold Markets](https://manifold.markets/home) data. Currently has bindings for their API, and code for computing various accuracy metrics (Brier score, log score, calibration).\


[Full Documentation](https://manifold-markets-python.readthedocs.io/en/latest/).
